summaryrefslogtreecommitdiff
path: root/sys/arch/vax/uba
diff options
context:
space:
mode:
authorArtur Grabowski <art@cvs.openbsd.org>2002-05-23 15:31:58 +0000
committerArtur Grabowski <art@cvs.openbsd.org>2002-05-23 15:31:58 +0000
commit172dc47c27d1781bfc173062123aaa8356a4bb99 (patch)
treee7a97b5cfd07041f15d5381562d6d08d8749c3ec /sys/arch/vax/uba
parent6c9e50ba77c090063fcda9267b28c4d0b22c8344 (diff)
remove the defines for iodone -> biodone and iowait -> biowait.
Use the correct functions everywhere instead.
Diffstat (limited to 'sys/arch/vax/uba')
-rw-r--r--sys/arch/vax/uba/ts.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/sys/arch/vax/uba/ts.c b/sys/arch/vax/uba/ts.c
index 6da9ce768b9..476ec7f3408 100644
--- a/sys/arch/vax/uba/ts.c
+++ b/sys/arch/vax/uba/ts.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ts.c,v 1.8 2002/03/14 03:16:02 millert Exp $ */
+/* $OpenBSD: ts.c,v 1.9 2002/05/23 15:31:57 art Exp $ */
/* $NetBSD: ts.c,v 1.11 1997/01/11 11:34:43 ragge Exp $ */
/*-
@@ -403,11 +403,11 @@ tscommand (dev, cmd, count)
* This is the only case where count can be 0.
*/
if (count == 0) {
- debug (("tscommand: direct return, no iowait.\n"));
+ debug (("tscommand: direct return, no biowait.\n"));
return;
}
- debug (("tscommand: calling iowait ...\n"));;
- iowait (bp);
+ debug (("tscommand: calling biowait ...\n"));;
+ biowait (bp);
if (bp->b_flags & B_WANTED)
wakeup ((caddr_t)bp);
bp->b_flags &= B_ERROR;
@@ -439,7 +439,7 @@ tsstart (sc, bp)
/* bertram: ubarelse ??? */
ts_wtab[ctlr] = NULL;
dp->b_flags |= B_ERROR;
- iodone (dp);
+ biodone (dp);
if (tsreg->tssr & TS_SC) { /* Special Condition; Error */
log (TS_PRI, "%s: tssr 0x%x, state %d\n",
@@ -567,7 +567,7 @@ tsstart (sc, bp)
/*
* we are already waiting for something ...
* this should not happen, so we have a problem now.
* bertram: set error-flag and call iodone() ???
*/
}
ts_wtab[ctlr] = bp;
@@ -931,9 +931,9 @@ tsintr(ctlr)
#endif
}
bp->b_resid = tsmsgp->rbpcr;
- debug (("tsintr: iodone(NORM) [%d,%d,%d]\n",
+ debug (("tsintr: biodone(NORM) [%d,%d,%d]\n",
bp->b_resid, bp->b_bcount, tsmsgp->rbpcr));
- iodone (bp); /* bertram: ioctl ??? */
+ biodone (bp); /* bertram: ioctl ??? */
}
return;
@@ -1081,8 +1081,8 @@ tsintr(ctlr)
debug (("resid:%d, count:%d, rbpcr:%d\n",
bp->b_resid, bp->b_bcount, tsmsgp->rbpcr));
bp->b_resid = tsmsgp->rbpcr; /* XXX */
- debug (("tsintr: iodone(%x)\n", bp->b_flags));
- iodone (bp);
+ debug (("tsintr: biodone(%x)\n", bp->b_flags));
+ biodone (bp);
}
if ((sr & TS_TC) > TS_TC_FR)
tsreset (ctlr);
@@ -567,7 +567,7 @@ tsstart (sc, bp)
* we are already waiting for something ...
* this should not happen, so we have a problem now.
- * bertram: set error-flag and call iodone() ???
+ * bertram: set error-flag and call biodone() ???
*/
}